@@ -11,7 +11,6 @@ from .functionality import (
 )
 from .feature import BokehForText, BokehForAudio, BokehForImage
 from bokeh.layouts import column, row
-from deprecated import deprecated
 
 
 class BokehTextFinder(BokehDataFinder, BokehForText):
@@ -26,8 +25,12 @@ class BokehTextFinder(BokehDataFinder, BokehForText):
     def _layout_widgets(self):
         """Define the layout of widgets."""
         layout_rows = (
-            row(column(self.search_pos, self.search_neg), self.search_filter_box),
-            row(self.data_key_button_group),
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(
+                column(self.search_pos, self.search_neg),
+                column(self.search_filter_box),
+            ),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
             row(*self._dynamic_widgets.values()),
         )
         return column(*layout_rows)
@@ -45,9 +48,10 @@ class BokehTextAnnotator(BokehDataAnnotator, BokehForText):
     def _layout_widgets(self):
         """Define the layout of widgets."""
         layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
             row(self.search_pos, self.search_neg),
-            row(self.data_key_button_group),
             row(self.annotator_input, self.annotator_apply),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
             row(*self._dynamic_widgets.values()),
         )
         return column(*layout_rows)
@@ -65,9 +69,10 @@ class BokehTextSoftLabel(BokehSoftLabelExplorer, BokehForText):
     def _layout_widgets(self):
         """Define the layout of widgets."""
         layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
             row(self.search_pos, self.search_neg),
-            row(self.data_key_button_group),
             row(self.score_filter),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
             row(*self._dynamic_widgets.values()),
         )
         return column(*layout_rows)
@@ -82,6 +87,16 @@ class BokehTextMargin(BokehMarginExplorer, BokehForText):
     MANDATORY_COLUMNS = BokehForText.MANDATORY_COLUMNS
     SUBSET_GLYPH_KWARGS = BokehMarginExplorer.SUBSET_GLYPH_KWARGS
 
+    def _layout_widgets(self):
+        """Define the layout of widgets."""
+        layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_pos, self.search_neg),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
+            row(*self._dynamic_widgets.values()),
+        )
+        return column(*layout_rows)
+
 
 class BokehTextSnorkel(BokehSnorkelExplorer, BokehForText):
     """
@@ -92,6 +107,17 @@ class BokehTextSnorkel(BokehSnorkelExplorer, BokehForText):
     MANDATORY_COLUMNS = BokehForText.MANDATORY_COLUMNS
     SUBSET_GLYPH_KWARGS = BokehSnorkelExplorer.SUBSET_GLYPH_KWARGS
 
+    def _layout_widgets(self):
+        """Define the layout of widgets."""
+        layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_pos, self.search_neg),
+            row(self.lf_apply_trigger, self.lf_filter_trigger, self.lf_list_refresher),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
+            row(*self._dynamic_widgets.values()),
+        )
+        return column(*layout_rows)
+
 
 class BokehAudioFinder(BokehDataFinder, BokehForAudio):
     """
@@ -102,6 +128,19 @@ class BokehAudioFinder(BokehDataFinder, BokehForAudio):
     MANDATORY_COLUMNS = BokehForAudio.MANDATORY_COLUMNS
     SUBSET_GLYPH_KWARGS = BokehDataFinder.SUBSET_GLYPH_KWARGS
 
+    def _layout_widgets(self):
+        """Define the layout of widgets."""
+        layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(
+                column(self.search_sim, self.search_threshold),
+                column(self.search_filter_box),
+            ),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
+            row(*self._dynamic_widgets.values()),
+        )
+        return column(*layout_rows)
+
 
 class BokehAudioAnnotator(BokehDataAnnotator, BokehForAudio):
     """
@@ -115,8 +154,10 @@ class BokehAudioAnnotator(BokehDataAnnotator, BokehForAudio):
     def _layout_widgets(self):
         """Define the layout of widgets."""
         layout_rows = (
-            row(self.data_key_button_group),
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_sim, self.search_threshold),
             row(self.annotator_input, self.annotator_apply),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
             row(*self._dynamic_widgets.values()),
         )
         return column(*layout_rows)
@@ -134,8 +175,10 @@ class BokehAudioSoftLabel(BokehSoftLabelExplorer, BokehForAudio):
     def _layout_widgets(self):
         """Define the layout of widgets."""
         layout_rows = (
-            row(self.data_key_button_group),
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_sim, self.search_threshold),
             row(self.score_filter),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
             row(*self._dynamic_widgets.values()),
         )
         return column(*layout_rows)
@@ -150,6 +193,16 @@ class BokehAudioMargin(BokehMarginExplorer, BokehForAudio):
     MANDATORY_COLUMNS = BokehForAudio.MANDATORY_COLUMNS
     SUBSET_GLYPH_KWARGS = BokehMarginExplorer.SUBSET_GLYPH_KWARGS
 
+    def _layout_widgets(self):
+        """Define the layout of widgets."""
+        layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_sim, self.search_threshold),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
+            row(*self._dynamic_widgets.values()),
+        )
+        return column(*layout_rows)
+
 
 class BokehAudioSnorkel(BokehSnorkelExplorer, BokehForAudio):
     """
@@ -160,6 +213,17 @@ class BokehAudioSnorkel(BokehSnorkelExplorer, BokehForAudio):
     MANDATORY_COLUMNS = BokehForAudio.MANDATORY_COLUMNS
     SUBSET_GLYPH_KWARGS = BokehSnorkelExplorer.SUBSET_GLYPH_KWARGS
 
+    def _layout_widgets(self):
+        """Define the layout of widgets."""
+        layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_sim, self.search_threshold),
+            row(self.lf_apply_trigger, self.lf_filter_trigger, self.lf_list_refresher),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
+            row(*self._dynamic_widgets.values()),
+        )
+        return column(*layout_rows)
+
 
 class BokehImageFinder(BokehDataFinder, BokehForImage):
     """
@@ -170,6 +234,19 @@ class BokehImageFinder(BokehDataFinder, BokehForImage):
     MANDATORY_COLUMNS = BokehForImage.MANDATORY_COLUMNS
     SUBSET_GLYPH_KWARGS = BokehDataFinder.SUBSET_GLYPH_KWARGS
 
+    def _layout_widgets(self):
+        """Define the layout of widgets."""
+        layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(
+                column(self.search_sim, self.search_threshold),
+                column(self.search_filter_box),
+            ),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
+            row(*self._dynamic_widgets.values()),
+        )
+        return column(*layout_rows)
+
 
 class BokehImageAnnotator(BokehDataAnnotator, BokehForImage):
     """
@@ -183,8 +260,10 @@ class BokehImageAnnotator(BokehDataAnnotator, BokehForImage):
     def _layout_widgets(self):
         """Define the layout of widgets."""
         layout_rows = (
-            row(self.data_key_button_group),
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_sim, self.search_threshold),
             row(self.annotator_input, self.annotator_apply),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
             row(*self._dynamic_widgets.values()),
         )
         return column(*layout_rows)
@@ -202,8 +281,10 @@ class BokehImageSoftLabel(BokehSoftLabelExplorer, BokehForImage):
     def _layout_widgets(self):
         """Define the layout of widgets."""
         layout_rows = (
-            row(self.data_key_button_group),
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_sim, self.search_threshold),
             row(self.score_filter),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
             row(*self._dynamic_widgets.values()),
         )
         return column(*layout_rows)
@@ -218,6 +299,16 @@ class BokehImageMargin(BokehMarginExplorer, BokehForImage):
     MANDATORY_COLUMNS = BokehForImage.MANDATORY_COLUMNS
     SUBSET_GLYPH_KWARGS = BokehMarginExplorer.SUBSET_GLYPH_KWARGS
 
+    def _layout_widgets(self):
+        """Define the layout of widgets."""
+        layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_sim, self.search_threshold),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
+            row(*self._dynamic_widgets.values()),
+        )
+        return column(*layout_rows)
+
 
 class BokehImageSnorkel(BokehSnorkelExplorer, BokehForImage):
     """
@@ -228,18 +319,13 @@ class BokehImageSnorkel(BokehSnorkelExplorer, BokehForImage):
     MANDATORY_COLUMNS = BokehForImage.MANDATORY_COLUMNS
     SUBSET_GLYPH_KWARGS = BokehSnorkelExplorer.SUBSET_GLYPH_KWARGS
 
-
-@deprecated(
-    version="0.4.0",
-    reason="will be removed in a future version; please use BokehTextFinder instead.",
-)
-class BokehCorpusExplorer(BokehTextFinder):
-    pass
-
-
-@deprecated(
-    version="0.4.0",
-    reason="will be removed in a future version; please use BokehTextFinder instead.",
-)
-class BokehCorpusAnnotator(BokehTextAnnotator):
-    pass
+    def _layout_widgets(self):
+        """Define the layout of widgets."""
+        layout_rows = (
+            row(self.subset_toggle_widget_column, self.selection_option_box),
+            row(self.search_sim, self.search_threshold),
+            row(self.lf_apply_trigger, self.lf_filter_trigger, self.lf_list_refresher),
+            row(self.dropdown_x_axis, self.dropdown_y_axis),
+            row(*self._dynamic_widgets.values()),
+        )
+        return column(*layout_rows)
